@@ -3,17 +3,16 @@ package Compress::Snappy;
 use strict;
 use warnings;
 
-use Exporter;
+use Exporter qw(import);
 use XSLoader;
 
-our $VERSION    = '0.22';
+our $VERSION    = '0.23';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
 XSLoader::load(__PACKAGE__, $XS_VERSION);
 
 our @EXPORT = qw(compress decompress uncompress);
-*import = \&Exporter::import;
 
 
 1;
@@ -148,7 +147,7 @@ L<http://search.cpan.org/dist/Compress-Snappy/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2013 gray <gray at cpan.org>, all rights reserved.
+Copyright (C) 2011-2014 gray <gray at cpan.org>, all rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
